<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       mailto:taras.sych@gmail.com
 * @since      1.0.0
 *
 * @package    Woo_Floating_Wishlist
 * @subpackage Woo_Floating_Wishlist/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Woo_Floating_Wishlist
 * @subpackage Woo_Floating_Wishlist/public
 * @author     Taras Sych <taras.sych@gmail.com>
 */
class Woo_Floating_Wishlist_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Woo_Floating_Wishlist_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Woo_Floating_Wishlist_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_style( 'dashicons' );
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/woo-floating-wishlist-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Woo_Floating_Wishlist_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Woo_Floating_Wishlist_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( 'skinnycookies', plugin_dir_url( __FILE__ ) . 'js/skinny.cookies.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/woo-floating-wishlist-public.js', array( 'skinnycookies', 'jquery' ), $this->version, false );
		wp_localize_script( $this->plugin_name, 'ajax_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );

	}

	/**
	 * Ajax backend to get product into
	 *
	 * @since    1.0.0
	 */
	public function get_wish_product() {
		// $action = ( isset($_POST['action']) ) ? $_POST['action'] : false;
		$wish_product_id = ( isset($_POST['wish_product_id']) ) ? intval($_POST['wish_product_id']) : false;

		$result = array();

		if ( $wish_product_id > 0 ) {
			$product = wc_get_product( $wish_product_id );
			if ( is_object($product) && $product instanceof WC_Product_Simple ) {
				$thumb_image = wp_get_attachment_image_src($product->get_image_id());

				$result['status'] = 'ok';
				$result['img'] = $thumb_image[0];
				$result['title'] = $product->get_title();
				$result['price'] = html_entity_decode(strip_tags($product->get_price_html()));
				$result['permalink'] = $product->get_permalink();
			} else {
				$result['status'] = 'fail';
				$result['error'] = 'Product not found';
			}
		} else {
			$result['status'] = 'fail';
			$result['error'] = 'Empty Product ID';
		}


		//
		// $wishlist_products = ( isset($_COOKIE['wfwl_wishlist_products']) ) ? json_decode($_COOKIE['wfwl_wishlist_products'], true) : array();
		// if ( !is_array($wishlist_products) ) $wishlist_products = array();
		//
		// $result = array();
		//
		// if ( $action && $action == 'wfwl_wish_product' && $wish_product_id > 0 ) {
		// 	// add new product id into cookies list
		//
		// 	if ( !in_array($wish_product_id, $wishlist_products) ) array_unshift($wishlist_products, $wish_product_id);
		//
		// 	setcookie('wfwl_wishlist_products', json_encode($wishlist_products), time()+3600);
		//
		// 	$result['status'] = 'ok';
		// 	$result['wishlist'] = $wishlist_products;
		// } else {
		// 	$result['status'] = 'fail';
		// }
		//
		echo json_encode($result);
		wp_die();
	}

	/**
	 * Display Wish button near Add to Cart button
	 *
	 * @since    1.0.0
	 */
	public function add_wish_button_after_cart_button( $button, $product, $args ) {
		$wish_btn_html = sprintf('<a href="%s" class="%s" id="%s" data-wish-product-id="%s">%s</a>',
			'#',
			'wfwl-wish-btn',
			'wfwl-wish-btn-'.$product->get_id(),
			$product->get_id(),
			'Wish it'
		);
		return $button.$wish_btn_html;
	}

	/**
	 * Display Wish button near Add to Cart button on single product page
	 *
	 * @since    1.0.0
	 */
	public function add_wish_button_after_cart_button_single( ) {
		$productID = get_the_ID();
		$wish_btn_html = sprintf('<a href="%s" class="%s" id="%s" data-wish-product-id="%s">%s</a>',
			'#',
			'wfwl-wish-btn',
			'wfwl-wish-btn-'.$productID,
			$productID,
			'Wish it'
		);
		echo $button.$wish_btn_html;
	}

	/**
	 * Display WishList bar
	 *
	 * @since    1.0.0
	 */
	public function wishlist_html() {
		$wishlist_html = sprintf('<div class="%s" id="%s"><span class="%s" title="%s"></span></div>',
			'wfwl-wishlist-cont hidden',
			'wfwl-wishlist-cont',
			'wfwl-wishlist-close',
			'Clear & Close'
		);
		echo $wishlist_html;
	}

}
