(function( $ ) {
	'use strict';

	function rebuild_wishlist() {
		if ( $("#wfwl-wishlist-cont").length > 0 && $.cookies.enabled() ) {
			var wishlist = [];

			if ( $.cookies.get("wfwl_wishlist_products") ) {
				wishlist = Object.values($.cookies.get("wfwl_wishlist_products")).reverse();
			}

			if ( wishlist.length > 0 && $(".wfwl-wishlist-cont").hasClass('hidden')) {
				$(".wfwl-wishlist-cont").removeClass('hidden');
			}

			wishlist.forEach(function (product_id, index) {
				setTimeout(function() {
				    add_wish_product(product_id, true);
				}, index * 200)
			});
		}
	}

	function add_wish_product(product_id) {
		if ( !$("#wfwl-wishlist-cont").length ) return;
		if ( !parseInt(product_id) ) return;

		var wishlist_cont = $("#wfwl-wishlist-cont");

		var wish_product = $("<div/>");
		wish_product.addClass('wish-one-product loading').attr('data-wish-product-id', product_id);

		wishlist_cont.addClass('heartbeat').delay(250).queue(function(){
		   $(this).removeClass('heartbeat');
		   $(this).dequeue();
		});

		if ( $(".wfwl-wishlist-cont").hasClass('hidden')) {
			$(".wfwl-wishlist-cont").removeClass('hidden');
		}

		wishlist_cont.prepend(wish_product); // prepend with loading graphic

		var data = {
			'action': 'wfwl_get_wish_product',
			'wish_product_id': product_id
		};

		jQuery.post(ajax_object.ajax_url, data, function(response) {
			if ( response.status == 'ok' ) {
				var wish_link_btn = $("<a/>").addClass('wish-link-btn').attr('href', response.permalink);
				var wish_thumb = $("<img/>").addClass('wish-thumb').attr('src', response.img).attr('title', response.title+' '+response.price);
				wish_product.append(wish_link_btn.append(wish_thumb)).removeClass('loading');
			} else {
				wish_product.fadeOut().remove();
			}
		}, "json");
	}

	function clear_wish_stack() {
		if ( $(".wish-one-product").length > 0 ) {
			if ( $.cookies.enabled() ) {
				if ( $.cookies.get("wfwl_wishlist_products") ) {
					var wishlist = Object.values($.cookies.get("wfwl_wishlist_products"));

					$(".wish-one-product").each(function(){
						var one_wish_product = $(this);
						var wish_product_id = one_wish_product.data("wish-product-id");

						if ( !wishlist.includes(String(wish_product_id)) ) {
							one_wish_product.fadeOut(200).remove();
						}
					});
				}
			}
		}
	}

	$(function() {
		// console.log('floating wishlist init');

		// $.cookies.remove("wfwl_wishlist_products"); // clear cookies

		$('body').on('click', '.wfwl-wishlist-close', function (e) {
			if ( $.cookies.enabled() ) {
				$.cookies.remove("wfwl_wishlist_products");
			}

			$(".wfwl-wishlist-cont").addClass('hidden');
			$(".wfwl-wishlist-cont .wish-one-product").remove();
		});

		$('body').on('click', '.wfwl-wish-btn', function (e) {
			e.preventDefault();

			var wish_btn = $(this);
			var wishlist = [];
			var wish_product_id = wish_btn.data("wish-product-id");

			if ( $.cookies.enabled() ) {
				if ( $.cookies.get("wfwl_wishlist_products") ) {
					wishlist = Object.values($.cookies.get("wfwl_wishlist_products"));
				}

				if ( !wishlist.includes(String(wish_product_id)) ) {
					wishlist.unshift(wish_product_id);
					wishlist = wishlist.slice(0, 5);
					add_wish_product(wish_product_id);
				}

				$.cookies.set("wfwl_wishlist_products", wishlist);
				clear_wish_stack();

			}

			// $.cookies.set("wfwl_wishlist_products", { id: "12345", favoriteColor: "blue" });
			//
			// var data = {
			// 	'action': 'wfwl_wish_product',
			// 	'wish_product_id': wish_product_id     // We pass php values differently!
			// };
			//
			// jQuery.post(ajax_object.ajax_url, data, function(response) {
			// 	console.log(response);
			// });


			// console.log("wish clicked");
			// console.log(wish_product_id);

			return false;
		});

		rebuild_wishlist();
	});

	/**
	 * All of the code for your public-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

})( jQuery );
