<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              mailto:taras.sych@gmail.com
 * @since             1.0.0
 * @package           Woo_Floating_Wishlist
 *
 * @wordpress-plugin
 * Plugin Name:       Floating Wishlist for Woo
 * Plugin URI:        https://wordpress.org/plugins/floating-wishlist-for-woo/
 * Description:       Simple to install, Always on Display WishList plugin for your WooCommerce store.
 * Version:           1.0.1
 * Author:            Taras Sych
 * Author URI:        mailto:taras.sych@gmail.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       woo-floating-wishlist
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'WOO_FLOATING_WISHLIST_VERSION', '1.0.1' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-woo-floating-wishlist-activator.php
 */
function activate_woo_floating_wishlist() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-woo-floating-wishlist-activator.php';
	Woo_Floating_Wishlist_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-woo-floating-wishlist-deactivator.php
 */
function deactivate_woo_floating_wishlist() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-woo-floating-wishlist-deactivator.php';
	Woo_Floating_Wishlist_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_woo_floating_wishlist' );
register_deactivation_hook( __FILE__, 'deactivate_woo_floating_wishlist' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-woo-floating-wishlist.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_woo_floating_wishlist() {

	$plugin = new Woo_Floating_Wishlist();
	$plugin->run();

}
run_woo_floating_wishlist();
